SystemOrganization addCategory: #ConfigurationOfRoassal!

Object subclass: #ConfigurationOfRoassal
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfRoassal'!

!ConfigurationOfRoassal class methodsFor: 'development support' stamp: ''!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfRoassal class methodsFor: 'private' stamp: ''!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfRoassal class methodsFor: 'private' stamp: ''!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfRoassal class methodsFor: 'private' stamp: ''!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfRoassal class methodsFor: 'metacello tool support' stamp: ''!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfRoassal class methodsFor: 'loading' stamp: ''!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfRoassal class methodsFor: 'loading' stamp: ''!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfRoassal class methodsFor: 'loading' stamp: ''!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfRoassal class methodsFor: 'accessing' stamp: ''!
project

	^self new project! !

!ConfigurationOfRoassal class methodsFor: 'development support' stamp: ''!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfRoassal methodsFor: 'baselines' stamp: 'AlexandreBergel 8/20/2013 21:33'!
baseline15: spec
	<version: '0.5-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: '1.289 : cleaning and refactoring
1.290 : - Correctly implemented layout start, step and end announcement support.
- Fixed a bug related to layout creation.

Thanks Dennis Schenk!!
1.292 : removed unused method and added a comment
1.293 : added a small comment
1.294 : Fix by Juraj.
1.295 : fixing undeterministic tests with force layout
1.296 : Integrated many fixes
1.297 : Fixed Issue 307:	Bug when exporting SVG
1.298 : Added a superclass ROAbstractPopupTest. A bit of cleaning
1.299 : Fixed Issue 308:	Large popup in the wrong place
1.300 : Fixed Issue 309:	empty categories are listed in the examples
1.301 : Roassal example about drawing
1.302 : Fixed Issue 310:	Slow with inner nodes
1.303 : Having edges that show up when you enter a node is a recurrent need.
I have worked on some easy way to make this possible.

Using the Roassal low level api:
-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
| view rawView el1 el2 el3 |
rawView := ROView new.
rawView add: (el1 := ROBox element size: 20).
rawView add: (el2 := ROBox element size: 20).
rawView add: (el3 := ROBox element size: 20).
ROCircleLayout on: (Array with: el1 with: el2 with: el3).
	
el1 @ RODraggable.
el2 @ RODraggable.
el3 @ RODraggable.
	
el1 @ (RODynamicEdge toAll: (Array with: el2 with: el3) using: (ROLine arrowed color: Color red)).

rawView open
-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=


Using the Mondrian builder:
-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
view interaction 
	dynamicEdge: [ :model | (Array with: 10 with: 20 with: 30) copyWithout: model ]
	using: (ROLine arrowed color: Color red).
view shape rectangle size: 20.
view nodes: (Array with: 10 with: 20 with: 30).
view circleLayout.
-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

1.304 : 
	- Fixed Issue 311:	ROHorizontalLineLayout>>positionOriginalPointer: buggy
	- cleaned a bit
	- testing ROPharoHTMLExporterTest
1.305 : Fixed Issue 311:	ROHorizontalLineLayout>>positionOriginalPointer: buggy
1.306 : merged
1.307 : Merged
1.308 : Fixing Roassal.Core.Tests.ROEventTest.testProperlyInitialized 
1.309 : Fixed Issue 312:	Bugfix for ROTreeMapLayout
1.310 : Fixed Issue 313:	RODynamicEdge cannot be combined
1.311 : Big big speed improvement
1.312 : 
Fixed Issue 314:	Freezing the image with Otho lines
	
Apparently lineSegmentsFor: returns an empty collection for Ortho lines. Which is obviously wrong.
1.312 : Fixed Issue 317:	expectedFailures in Roassal is not properly defined
	- merged with Vanessa code
	Added ROMondrianViewBuilder >> removeNodesAndEdgesOf: so Juampi can remove nodes and edges easily :D
- fixed issue: 315 with applying layout after removing and adding nodes 
- fixed RoassalSerializerExporterTest  expected failures
- tests added
1.314 : 
	- Included Mathieu works on the radial tree layout 
	- Added Bezier Curve
	- Fix by Milton on making Roassal importable in VisualWorks
1.315 : Added a test for the radial tree layout
1.409 : Included fix from Dennis for the two failing tests of the treemap
1.409 : Included fix for the two failing tests of Dennis
1.410 : simplified ROAttachPointTest>>setUp'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/20/2013 21:33'.
		spec repository: 'http://www.smalltalkhub.com/mc/ObjectProfile/Roassal/main'.
		spec 
			package: #Roassal;
			package: #RoassalMorphic.
		spec 
			group: 'default' with: #(#Roassal #RoassalMorphic );
			group: 'Tests' with: #(#Roassal #RoassalMorphic ). ].
! !

!ConfigurationOfRoassal methodsFor: 'symbolic versions' stamp: 'AlexandreBergel 8/12/2013 14:20'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '0.5-baseline'.
! !

!ConfigurationOfRoassal methodsFor: 'accessing' stamp: ''!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfRoassal methodsFor: 'symbolic versions' stamp: 'AlexandreBergel 8/12/2013 19:15'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.408'.
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/15/2013 18:30'!
version1400: spec
	<version: '1.400' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.400 : Fixed Issue 348:	horizontalOutGap: and verticalOutGap: are not necessary'.
		spec author: 'AlexandreBergel'.
		spec timestamp: 'AlexandreBergel 8/11/2013 17:28'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.637';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.142'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/15/2013 18:30'!
version1401: spec
	<version: '1.401' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.401 : fix with the Diamond test'.
		spec author: 'AlexandreBergel'.
		spec timestamp: 'AlexandreBergel 8/11/2013 17:30'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.637';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.143'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/15/2013 18:30'!
version1402: spec
	<version: '1.402' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.402 : Removed testNoPadding6, which was not portable (fail on Jenkins)'.
		spec author: 'AlexandreBergel'.
		spec timestamp: 'AlexandreBergel 8/11/2013 17:42'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.638';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.143'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/15/2013 18:30'!
version1403: spec
	<version: '1.403' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.403:
- Issue 349:	Need a better way to define edges
- Issue 350:	Need to define better way for callbacks when modifying an element'.
		spec author: 'AlexandreBergel'.
		spec timestamp: 'AlexandreBergel 8/11/2013 22:18'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.639';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.143'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/15/2013 18:30'!
version1404: spec
	<version: '1.404' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.404 :
- Test for Issue 350:	Need to define better way for callbacks when modifying an element'.
		spec author: 'AlexandreBergel'.
		spec timestamp: 'AlexandreBergel 8/11/2013 22:29'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.640';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.143'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/15/2013 18:30'!
version1405: spec
	<version: '1.405' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.405: Fixed Issue 351:	MondrianViewBuilder should support a better zOrder'.
		spec author: 'AlexandreBergel'.
		spec timestamp: 'AlexandreBergel 8/12/2013 14:19'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.641';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.143'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/15/2013 18:30'!
version1406: spec
	<version: '1.406' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.406 : Fixed Issue 352:	Replacing elements in a container'.
		spec author: 'AlexandreBergel'.
		spec timestamp: 'AlexandreBergel 8/12/2013 18:49'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.641';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.143'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/15/2013 18:30'!
version1407: spec
	<version: '1.407' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.407 : Fixed Issue 353:	(ROLine buildEdgesFromElements: #() from: nil to: nil) raise en error, it should not'.
		spec author: 'AlexandreBergel'.
		spec timestamp: 'AlexandreBergel 8/12/2013 19:11'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.643';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.143'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/15/2013 18:30'!
version1408: spec
	<version: '1.408' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.408 : Failing test as expectedFailure. Waiting for Dennis to do something'.
		spec author: 'AlexandreBergel'.
		spec timestamp: 'AlexandreBergel 8/12/2013 19:15'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.643';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.143'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/15/2013 18:32'!
version1409: spec
	<version: '1.409' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.409 : Included fix for the two failing tests of Dennis'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/15/2013 18:32'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.645';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.143'. ].
! !
